Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(437)

Unified Diff: src/interpreter/bytecode-array-builder.h

Issue 2649143002: [Turbofan] Implement call with spread bytecode in assembly code. (Closed)
Patch Set: Rename PushArgsMode to InterpreterPushArgsMode Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/globals.h ('k') | src/interpreter/bytecode-array-builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/interpreter/bytecode-array-builder.h
diff --git a/src/interpreter/bytecode-array-builder.h b/src/interpreter/bytecode-array-builder.h
index 6d2605bd5f1c13ea995cbf4bd41483d422da8f95..7bb601b752c0c2a16da56876295baf894d60a46b 100644
--- a/src/interpreter/bytecode-array-builder.h
+++ b/src/interpreter/bytecode-array-builder.h
@@ -214,9 +214,9 @@ class V8_EXPORT_PRIVATE BytecodeArrayBuilder final
TailCallMode tail_call_mode = TailCallMode::kDisallow);
// Call a JS function. The JSFunction or Callable to be called should be in
// |args[0]|, the receiver in |args[1]| and the arguments in |args[2]|
// onwards. The final argument must be a spread.
- BytecodeArrayBuilder& CallWithSpread(RegisterList args);
+ BytecodeArrayBuilder& CallWithSpread(Register callable, RegisterList args);
// Call the new operator. The accumulator holds the |new_target|.
// The |constructor| is in a register and arguments are in |args|.
« no previous file with comments | « src/globals.h ('k') | src/interpreter/bytecode-array-builder.cc » ('j') | no next file with comments »
@@ -214,9 +214,9 @@ class V8_EXPORT_PRIVATE BytecodeArrayBuilder final
TailCallMode tail_call_mode = TailCallMode::kDisallow);
// Call a JS function. The JSFunction or Callable to be called should be in
- // |args[0]|, the receiver in |args[1]| and the arguments in |args[2]|
+ // |callable|, the receiver in |args[0]| and the arguments in |args[1]|
// onwards. The final argument must be a spread.

Powered by Google App Engine
This is Rietveld 408576698